@@ -13,12 +13,16 @@
     conflicting_repr_hints,
     confusable_idents,
     const_err,
+    const_evaluatable_unchecked,
+    const_item_mutation,
     dead_code,
     deprecated,
     deprecated_in_future,
+    drop_bounds,
     ellipsis_inclusive_range_patterns,
     explicit_outlives_requirements,
     exported_private_dependencies,
+    function_item_references,
     ill_formed_attribute_input,
     illegal_floating_point_literal_pattern,
     improper_ctypes,
@@ -28,6 +32,7 @@
     indirect_structural_match,
     inline_no_sanitize,
     invalid_codeblock_attributes,
+    invalid_html_tags,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
@@ -48,11 +53,13 @@
     non_shorthand_field_patterns,
     non_snake_case,
     non_upper_case_globals,
+    nontrivial_structural_match,
     order_dependent_trait_objects,
     overflowing_literals,
     overlapping_patterns,
     path_statements,
     patterns_in_fns_without_body,
+    pointer_structural_match,
     private_doc_tests,
     private_in_public,
     proc_macro_derive_resolution_fallback,
@@ -61,6 +68,7 @@
     safe_packed_borrows,
     soft_unstable,
     stable_features,
+    temporary_cstring_as_ptr,
     trivial_bounds,
     trivial_casts,
     trivial_numeric_casts,
@@ -70,6 +78,7 @@
     uncommon_codepoints,
     unconditional_panic,
     unconditional_recursion,
+    uninhabited_static,
     unknown_crate_types,
     unnameable_test_items,
     unreachable_code,
@@ -98,7 +107,8 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
-    where_clauses_object_safety
+    where_clauses_object_safety,
+    while_true
 )]
 #![warn(macro_use_extern_crate, unknown_lints)]
 #![allow(
